@@ -305,7 +305,7 @@ class FindElementsMixin:
         }
         provided_selectors = {key: value for key, value in simple_selectors.items() if value}
 
-        if len(provided_selectors) == 1 and not text:
+        if len(provided_selectors) == 1 and not text and not attributes:
             key, value = next(iter(provided_selectors.items()))
             by = by_map[key]
             return by, value
@@ -403,8 +403,8 @@ class FindElementsMixin:
         if object_id and not by == By.XPATH:
             script = Scripts.RELATIVE_QUERY_SELECTOR.replace('{selector}', selector)
             command = RuntimeCommands.call_function_on(
-                object_id,
-                script,
+                function_declaration=script,
+                object_id=object_id,
                 return_by_value=False,
             )
         elif by == By.XPATH:
@@ -437,8 +437,8 @@ class FindElementsMixin:
         if object_id and not by == By.XPATH:
             script = Scripts.RELATIVE_QUERY_SELECTOR_ALL.replace('{selector}', escaped_value)
             command = RuntimeCommands.call_function_on(
-                object_id,
-                script,
+                function_declaration=script,
+                object_id=object_id,
                 return_by_value=False,
             )
         elif by == By.XPATH:
@@ -461,8 +461,8 @@ class FindElementsMixin:
             escaped_value = self._ensure_relative_xpath(escaped_value)
             script = Scripts.FIND_RELATIVE_XPATH_ELEMENT.replace('{escaped_value}', escaped_value)
             command = RuntimeCommands.call_function_on(
-                object_id,
-                script,
+                function_declaration=script,
+                object_id=object_id,
                 return_by_value=False,
             )
         else:
